package com.example.fieldagent.utils

import android.text.format.DateUtils

import java.text.SimpleDateFormat
import java.util.*


object DateUtils {

    val utcFormat = SimpleDateFormat(DateFormat.UTC_FORMAT_NORMAL, Locale.ENGLISH)



    fun getTimeAgo(createdAt: String?): String {
        if (createdAt == null) return ""

        return try {
            val utcFormat = SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSS'Z'", Locale.getDefault())
            utcFormat.timeZone = TimeZone.getTimeZone("UTC")

            val pastTime = utcFormat.parse(createdAt)?.time ?: return ""
            val now = System.currentTimeMillis()

            val seconds = (now - pastTime) / 1000
            val minutes = seconds / 60
            val hours = minutes / 60
            val days = hours / 24

            return when {
                seconds < 60 -> "$seconds seconds ago"
                minutes < 60 -> "$minutes minutes ago"
                hours < 24 -> "$hours hours ago"
                days < 7 -> "$days days ago"
                else -> {
                    val outputFormat = SimpleDateFormat("dd MMM yyyy", Locale.getDefault())
                    outputFormat.format(Date(pastTime))
                }
            }
        } catch (e: Exception) {
            e.printStackTrace()
            ""
        }
    }

}



object DateFormat {
    const val DATE_FORMAT = "yyyy-MM-dd"
    const val DATE_TIME_FORMAT = "MMM dd, yyyy · hh:mm a"
    const val DAY_DATE_FORMAT = "EEE · MMM dd, yyyy"
    const val TIME_FORMAT = "hh:mm a"
    const val TIME_FORMAT_24 = "HH:mm"
    const val MON_DATE_YEAR = "MMM dd, yyyy"
    const val MON_DATE = "MMM dd"
    const val DATE_FORMAT_SLASH_YEAR = "dd/MM/yyyy"
    const val UTC_FORMAT_NORMAL = "yyyy-MM-dd HH:mm:ss"
    const val UTC_FORMAT = "yyyy-MM-dd'T'HH:mm:ss.SSS'Z'"
    const val DATE = "dd"
    const val MONTH = "MM"
    const val YEAR = "yyyy"
    const val HH_24 = "HH"
    const val MM = "mm"
}
